@@ -1,10 +1,10 @@
 /*
-  Copyright (c) 2004        Dale Mellor, John Darrington
-  copyright (c) 1998, 2003  John Darrington
+  Copyright (c) 2004        Dale Mellor,  John Darrington
+  copyright (c) 1998,  2003  John Darrington
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License,  or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -13,19 +13,19 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 
 static const char RCSID []
-    = "$Id: cube.c,v 1.2 2004/01/07 10:23:34 jmd Exp $";
+    = "$Id: cube.c,v 1.4 2008/01/17 04:56:50 jmd Exp $";
 
 
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
 #include <math.h>
+#include <libguile.h>
 
 #include "cube.h"
 
@@ -34,7 +34,7 @@ static const char RCSID []
 /* Get this nonesense out of the way first! */
 Cube *the_cube = NULL;
 
-int create_the_cube (const unsigned dim) 
+int create_the_cube (const unsigned dim)
 {   return dim == 0 ? 0 : (the_cube = new_cube (dim))->number_blocks; }
 
 void destroy_the_cube (void)
@@ -43,11 +43,11 @@ void destroy_the_cube (void)
 
 
 
-/* Cube co-ordinates have their origin at the centre of the cube, and their
+/* Cube co-ordinates have their origin at the centre of the cube,  and their
    units are equivalent to one half of the length of one edge of a block. */
 /* This func initialises the positions of the blocks which comprise the cube.
    The enumeration scheme I have chosen goes around four surfaces of the cube,
-   then fills in the ends.  Thus, for a 4x4x4 cube it looks like:
+   then fills in the ends.  Thus,  for a 4x4x4 cube it looks like:
 
    ----------------------------------------------------------------------------
    View this diagram with 132 coloumns!
@@ -69,18 +69,18 @@ void destroy_the_cube (void)
  ******/
 
 /* Utility function to fetch a particular face of the cube. */
-inline Face *
-get_face (Cube *const cube, const int block, const int face)
+static inline Face *
+get_face (Cube *const cube,  const int block,  const int face)
 {
     return cube->blocks [block].face + face;
 }
 
-/* Set the centre point of the face to (x0, x1, x2, x3). */
-inline void
+/* Set the centre point of the face to (x0,  x1,  x2,  x3). */
+static inline void
 set_face_centre (Block *const block,
                  const int face,
-                 const GLfloat x0, const GLfloat x1,
-                 const GLfloat x2, const GLfloat x3)
+                 const GLfloat x0,  const GLfloat x1,
+                 const GLfloat x2,  const GLfloat x3)
 {
     point *const centre = & block->face [face].centre;
 
@@ -90,17 +90,19 @@ set_face_centre (Block *const block,
     (*centre) [3] = x3;
 }
 
-/* During the construction of the array of blocks, we start by assigning them
-   coordinates with components (0, 1, 2, ...), and then transform them to the
-   range (-(cube_size-1), -(cube_size-2), ..., 0, 1, 2, ..., cube_size-1); this
+/* During the construction of the array of blocks,  we start by assigning them
+   coordinates with components (0,  1,  2,  ...),  and then transform them to the
+   range (-(cube_size-1),  -(cube_size-2),  ...,  0,  1,  2,  ...,  cube_size-1); this
    function performs the transformation. Later on we will also be needing the
    inverse transformation. */
-inline int block_index_to_coords (const Cube *const cube, const int i)
+static inline int
+block_index_to_coords (const Cube *const cube,  const int i)
 {
     return 2 * i - (cube->cube_size - 1);
 }
 
-inline int block_coords_to_index (const Cube *const cube, const double i)
+static inline int
+block_coords_to_index (const Cube *const cube,  const double i)
 {
     return (int) ((i + (cube->cube_size - 1)) / 2.0);
 }
@@ -111,17 +113,17 @@ Cube *
 new_cube (const unsigned cube_size)
 {
     /* Looping variables. */
-    int i, k;
+    int i,  k;
 
     /* The object that is returned to the caller. */
     Cube *ret;
 
     /* We'll be needing this value quite a bit. */
     const unsigned cube_size_2 = cube_size * cube_size;
-    
 
-    /* Allocate memory, and initialize constant members of the cube. */
-    
+
+    /* Allocate memory,  and initialize constant members of the cube. */
+
     if (cube_size == 0)
         return NULL;
 
@@ -130,7 +132,7 @@ new_cube (const unsigned cube_size)
 
     ret->cube_size = cube_size;
     ret->number_blocks = cube_size_2 * cube_size;
-    
+
     if (NULL == (ret->blocks = (Block *)
                                   malloc (ret->number_blocks * sizeof (Block))))
     {
@@ -139,16 +141,16 @@ new_cube (const unsigned cube_size)
     }
 
 
-    /* Loop over the array of blocks, and initialize each one. */
- 
+    /* Loop over the array of blocks,  and initialize each one. */
+
     for (i = 0; i < ret->number_blocks; ++i)
     {
         Block *const block = ret->blocks + i;
-        
-        
+
+
         /* Flagging only certain faces as visible allows us to avoid rendering
-           invisible surfaces, thus slowing down animation. */
-	
+           invisible surfaces,  thus slowing down animation. */
+
         block->visible_faces
                    =   FACE_0 * (0 == i / cube_size_2)
                      + FACE_1 * (cube_size - 1 == i / cube_size_2)
@@ -157,37 +159,37 @@ new_cube (const unsigned cube_size)
                      + FACE_4 * (0 == i % cube_size)
                      + FACE_5 * (cube_size - 1 == i % cube_size);
 
-    
-        /* Initialize all transformations to the identity matrix, then set the
+
+        /* Initialize all transformations to the identity matrix,  then set the
            translation part to correspond to the initial position of the
            block. */
-    
+
         for (k = 0; k < 12; ++k)
             block->transformation [k] = 0;
         for (k = 0; k < 4; ++k)
             block->transformation [5 * k] = 1;
 
         block->transformation [12]
-                 = block_index_to_coords (ret, i % cube_size);
+                 = block_index_to_coords (ret,  i % cube_size);
         block->transformation [13]
-                 = block_index_to_coords (ret, (i / cube_size) % cube_size);
+                 = block_index_to_coords (ret,  (i / cube_size) % cube_size);
         block->transformation [14]
-                 = block_index_to_coords (ret, (i / cube_size_2) % cube_size);
-        
+                 = block_index_to_coords (ret,  (i / cube_size_2) % cube_size);
+
 
         /* Set all the face centres. */
 
-        set_face_centre (block, 0,  0,  0, -1, 0);
-        set_face_centre (block, 1,  0,  0,  1, 0);
-        set_face_centre (block, 2,  0, -1,  0, 0);
-        set_face_centre (block, 3,  0,  1,  0, 0);
-        set_face_centre (block, 4, -1,  0,  0, 0);
-        set_face_centre (block, 5,  1,  0,  0, 0);
-        
+        set_face_centre (block,  0,   0,   0,  -1,  0);
+        set_face_centre (block,  1,   0,   0,   1,  0);
+        set_face_centre (block,  2,   0,  -1,   0,  0);
+        set_face_centre (block,  3,   0,   1,   0,  0);
+        set_face_centre (block,  4,  -1,   0,   0,  0);
+        set_face_centre (block,  5,   1,   0,   0,  0);
+
     }  /* End of loop over blocks. */
 	
     return ret;
-    
+
 }  /* End of function new_cube (). */
 
 
@@ -204,7 +206,7 @@ free_cube (Cube *const cube)
     if (cube)
     {
         free (cube->blocks);
-        
+
         free (cube);
     }
 }
@@ -218,16 +220,16 @@ free_cube (Cube *const cube)
  *  NULL will not be supplied.
  ******/
 
-inline void
-set_block_error_message (Cube *const cube, const char *const msg)
+static inline void
+set_block_error_message (Cube *const cube,  const char *const msg)
 {
-    strncpy (cube->error_message, msg, BLOCK_ERROR_MESSAGE_BUFFER_LEN);
+    strncpy (cube->error_message,  msg,  BLOCK_ERROR_MESSAGE_BUFFER_LEN);
 }
 
 void
-print_cube_error (const Cube *const cube, const char *const prefix)
+print_cube_error (const Cube *const cube,  const char *const prefix)
 {
-    printf ("%s: %s\n", prefix, cube->error_message);
+    printf ("%s: %s\n",  prefix,  cube->error_message);
 }
 
 
@@ -239,7 +241,7 @@ print_cube_error (const Cube *const cube, const char *const prefix)
 
 /* Quick cosine function for angles expressed in quarters of complete
    revolutions. */
-inline int
+static inline int
 cos_quadrant (const int quarters)
 {
 	switch (abs (quarters) % 4)
@@ -250,16 +252,16 @@ cos_quadrant (const int quarters)
 	}
 }
 
-/* Quick sine function, for angles expressed in quarters of complete
+/* Quick sine function,  for angles expressed in quarters of complete
    revolutions. */
-inline int
+static inline int
 sin_quadrant (const int quarters)
 {
     return cos_quadrant (quarters - 1);
 }
 
-/* Rotate the slice identified by a prior call to identify_blocks, about the
-   axis, through an angle specified by turns, which is in quarters of complete
+/* Rotate the slice identified by a prior call to identify_blocks,  about the
+   axis,  through an angle specified by turns,  which is in quarters of complete
    revolutions. */
 int
 rotate_slice (Cube *const cube,
@@ -272,24 +274,24 @@ rotate_slice (Cube *const cube,
 	/* Create a matrix describing the rotation of we are about to perform.
        We do this by starting with the identity matrix... */
 	Matrix rotation = {
-		1,0,0,0,
-		0,1,0,0,
-		0,0,1,0,
-		0,0,0,1
+		1, 0, 0, 0,
+		0, 1, 0, 0,
+		0, 0, 1, 0,
+		0, 0, 0, 1
 	};
 
 
 	/* ... and then assigning values to the active elements. */
-    
+
 	rotation [(slice->axis + 1) % 3 + 4 * ((slice->axis + 1) % 3)]
         = cos_quadrant (turns);
-    
+
 	rotation [(slice->axis + 2) % 3 + 4 * ((slice->axis + 2) % 3)]
         = cos_quadrant (turns);
-    
+
 	rotation [(slice->axis + 1) % 3 + 4 * ((slice->axis + 2) % 3)]
         = sin_quadrant (turns);
-    
+
 	rotation [(slice->axis + 2) % 3 + 4 * ((slice->axis + 1) % 3)]
         = -sin_quadrant (turns);
 
@@ -300,7 +302,7 @@ rotate_slice (Cube *const cube,
 	for (i = slice->blocks + slice->number_blocks - 1;
          i >= slice->blocks;
          --i)
-		pre_mult (rotation, cube->blocks [*i].transformation);
+		pre_mult (rotation,  cube->blocks [*i].transformation);
 
 	return 0;
 
@@ -312,9 +314,9 @@ rotate_slice (Cube *const cube,
 /********************
  * Return a pointer to an array of block numbers which are in the slice
  * identified by slice_depth (two publicly-exposed wrappers defined below allow
- * for a convenient means of computing this), and axis (an integer in [0,
+ * for a convenient means of computing this),  and axis (an integer in [0,
  * 3)). The return value should eventually be destroyed with
- * free_slice_blocks().
+ * free_slice_blocks ().
  ******/
 
 Slice_Blocks *
@@ -328,16 +330,16 @@ identify_blocks_2 (Cube *const cube,
 
 
     /* Allocate memory for the return object. */
-    
+
     Slice_Blocks *const ret = (Slice_Blocks*) malloc (sizeof (Slice_Blocks));
-    
+
     if (! ret)
         return NULL;
-    
+
     ret->number_blocks = cube->cube_size * cube->cube_size;
-    
+
     ret->blocks = (int *) malloc (ret->number_blocks * sizeof (int));
-    
+
     if (! ret->blocks)
     {
         free (ret);
@@ -348,13 +350,13 @@ identify_blocks_2 (Cube *const cube,
     /* We need to pass the axis on to the rotate routine. */
 
     ret->axis = axis;
-    
+
 
     /* Iterate over all the blocks in the cube. When we find one whose
        axis-component of the location part of its transformation matrix
-       corresponds to the requested slice depth, then we make a note of its
+       corresponds to the requested slice depth,  then we make a note of its
        offset in the return->blocks array. */
-    
+
     for (i = cube->blocks + cube->number_blocks - 1; i >= cube->blocks; --i)
         if (fabs (i->transformation [12 + axis] - slice_depth) < 0.1)
             ret->blocks [j++] = i - cube->blocks;
@@ -388,14 +390,14 @@ identify_surface_blocks (Cube *const cube,
                          const unsigned axis)
 {
     if (axis < 3)
-        return identify_blocks_2 (cube, cube->cube_size - 1, axis);
+        return identify_blocks_2 (cube,  cube->cube_size - 1,  axis);
 
     else
         return identify_blocks_2 (cube,
                                   - (cube->cube_size - 1),
                                   axis - 3);
 }
-    
+
 
 
 
@@ -409,7 +411,7 @@ free_slice_blocks (Slice_Blocks *const slice)
     if (slice)
     {
         free (slice->blocks);
-        
+
         free (slice);
     }
 }
@@ -421,48 +423,30 @@ free_slice_blocks (Slice_Blocks *const slice)
  * Set the normal vector for block/face.
  ******/
 
-void 
+void
 set_normal_vector (Cube *const cube,
                    const unsigned block,
                    const unsigned face,
                    const vector v)
 {
     Matrix view;
-    vector *const dest = & get_face (cube, block, face)->normal;
+    vector *const dest = & get_face (cube,  block,  face)->normal;
 
-    glGetFloatv (GL_MODELVIEW_MATRIX, view);
+    glGetFloatv (GL_MODELVIEW_MATRIX,  view);
 
-    memcpy (dest, v, sizeof (vector));
+    memcpy (dest,  v,  sizeof (vector));
 
-    transform (view, *dest);
+    transform (view,  *dest);
 }
 
-
-
-
-/********************
- * Retrieve the normal vector for block/face.
- ******/
-
-void 
-get_normal_vector (const Cube *const cube,
-                   const unsigned block,
-                   const unsigned face,
-                   vector v)
-{
-    memcpy (v,
-            get_face ((Cube *const) cube, block, face)->normal,
-            sizeof (vector));
-}
-
-
-
 
+
+
 /********************
  * Set the vector for block/face/quadrant to v.
  ******/
 
-void 
+void
 set_quadrant_vector (Cube *const cube,
                      const unsigned block,
                      const unsigned face,
@@ -470,13 +454,13 @@ set_quadrant_vector (Cube *const cube,
                      const vector v)
 {
     Matrix view;
-    vector *const dest = get_face (cube, block, face)->quadrants + quadrant;
+    vector *const dest = get_face (cube,  block,  face)->quadrants + quadrant;
 
-    glGetFloatv(GL_MODELVIEW_MATRIX,view);
+    glGetFloatv (GL_MODELVIEW_MATRIX,  view);
 
-    memcpy (dest, v, sizeof (vector));
+    memcpy (dest,  v,  sizeof (vector));
 
-    transform (view, *dest);
+    transform (view,  *dest);
 }
 
 
@@ -486,15 +470,15 @@ set_quadrant_vector (Cube *const cube,
  * Return the quadrant vector in v.
  ******/
 
-void 
-get_quadrant_vector(const Cube *const cube,
+void
+get_quadrant_vector (const Cube *const cube,
                     const unsigned block,
                     const unsigned face,
                     const unsigned quadrant,
                     vector v)
 {
     memcpy (v,
-            get_face ((Cube *const) cube, block, face)->quadrants + quadrant,
+            get_face ((Cube *const) cube,  block,  face)->quadrants + quadrant,
             sizeof (vector));
 }
 
@@ -503,8 +487,8 @@ get_quadrant_vector(const Cube *const cube,
 
 /********************
  * The cube is solved iff for all faces the quadrant vectors point in the same
- * direction.  If however all the normals point in the same direction, but the
- * quadrants do not, then the colours are all on the right faces, but not
+ * direction.  If however all the normals point in the same direction,  but the
+ * quadrants do not,  then the colours are all on the right faces,  but not
  * correctly orientated.
  ******/
 
@@ -512,17 +496,17 @@ Cube_Status
 cube_status_check (const Cube *const cube)
 {
     /* Loop variables for iterating over faces and blocks. */
-    
+
     int face;
     Block *block;
 
-    
-    /* Find out if the cube is at least half solved (the colours are right, but
+
+    /* Find out if the cube is at least half solved (the colours are right,  but
        some orientations are wrong (this can be seen on a face away from an edge
        of the cube with a pixmap on it). If the cube is not at least
-       half-solved, then it is definitely unsolved and this value is
+       half-solved,  then it is definitely unsolved and this value is
        returned. */
-    
+
     for (face = 0; face < 6 ; ++face)
     {
         vector q0;
@@ -539,14 +523,14 @@ cube_status_check (const Cube *const cube)
 
                 if (x == 0)
                 {
-                    memcpy (q0, v0, sizeof(vector));
+                    memcpy (q0,  v0,  sizeof (vector));
 
                     ++x;
                 }
-                
+
                 else
                 {
-                    if (! vectors_equal (q0, *v0))
+                    if (! vectors_equal (q0,  *v0))
                         return NOT_SOLVED;
                 }
             }
@@ -555,10 +539,10 @@ cube_status_check (const Cube *const cube)
 
 
     /* The cube is at least half-solved. Check if it is fully solved by checking
-       the alignments of all the quadrant vectors. If any are out, then return
+       the alignments of all the quadrant vectors. If any are out,  then return
        the half-solved status to the caller. Note that it is only necessary to
        check two perpendicular quadrant vectors. */
-    
+
     for (face = 0; face < 6; ++face)
     {
         vector q1;
@@ -573,24 +557,24 @@ cube_status_check (const Cube *const cube)
             /* Ignore faces which are inside the cube. */
             if (block->visible_faces & mask)
             {
-                vector *const v0 = block->face [face].quadrants; 
+                vector *const v0 = block->face [face].quadrants;
                 vector *const v1 = v0 + 1;
 
                 if (x == 0)
                 {
-                    memcpy (q0, v0, sizeof (vector));
-                    memcpy (q1, v1, sizeof (vector));
-                    
+                    memcpy (q0,  v0,  sizeof (vector));
+                    memcpy (q1,  v1,  sizeof (vector));
+
                     ++x;
                 }
-                
-                else if (! vectors_equal (q0, *v0)
-                                            ||  ! vectors_equal (q1, *v1))
+
+                else if (! vectors_equal (q0,  *v0)
+                                            ||  ! vectors_equal (q1,  *v1))
                     return HALF_SOLVED;
             }
         }
     }
-    
+
     /* Cube is fully solved. */
     return SOLVED;
 }
@@ -602,8 +586,8 @@ cube_status_check (const Cube *const cube)
  * Cube accessor method.
  ******/
 
-int 
-get_visible_faces (const Cube *const cube, const unsigned block_id)
+int
+get_visible_faces (const Cube *const cube,  const unsigned block_id)
 {
     return cube->blocks [block_id].visible_faces;
 }
@@ -612,8 +596,8 @@ get_visible_faces (const Cube *const cube, const unsigned block_id)
 
 
 /********************
- * Get the transformation of block number `block_id' from the origin, and store
- * it in transform. Return 0 on success, 1 on error.
+ * Get the transformation of block number `block_id' from the origin,  and store
+ * it in transform. Return 0 on success,  1 on error.
  ******/
 
 int
@@ -628,15 +612,12 @@ get_block_transform (const Cube *const cube,
 	return 0;
 }
 
-
-
 
-#ifdef HAVE_GUILE
 
 /********************
  * Manufacture a SCM object which is a vector of six vectors of (cube_size *
- * cube_size) elements, each one holding the colour of a patch of the surface of
- * the cube (a number from [0,5]).
+ * cube_size) elements,  each one holding the colour of a patch of the surface of
+ * the cube (a number from [0, 5]).
  ********/
 
 SCM make_scm_cube (const Cube *const cube)
@@ -646,71 +627,71 @@ SCM make_scm_cube (const Cube *const cube)
     int face;
     char colours [6] [cube->cube_size] [cube->cube_size];
 
-    /* Loop over all blocks and faces, but only process if the face is on the
+    /* Loop over all blocks and faces,  but only process if the face is on the
        outside of the cube. */
-    
+
     for (block = cube->blocks + cube->number_blocks - 1;
          block >= cube->blocks;
          --block)
-        
+
         for (face = 0; face < 6; ++face)
-            
+
             if (block->visible_faces & (0x01 << face))
             {
                 /* Apply the rotation part of the block transformation to the
                    offset of the face centre from the centre of the block. This
                    will tell us the direction the face is now facing. */
-                
+
                 point face_direction;
 
                 memcpy (face_direction,
                         block->face [face].centre,
                         sizeof (point));
 
-                transform (block->transformation, face_direction);
+                transform (block->transformation,  face_direction);
 
 
                 /* The face direction will have exactly one non-zero component;
-                   this is in the direction of the normal, so we can infer which
-                   side of the cube we are on. Further, if we look at the other
+                   this is in the direction of the normal,  so we can infer which
+                   side of the cube we are on. Further,  if we look at the other
                    two components of the location part of the block
-                   transformation, we can infer the position of the block in the
+                   transformation,  we can infer the position of the block in the
                    face. We set the appropriate element in the colours array to
-                   the colour of this face, which corresponds exactly with the
+                   the colour of this face,  which corresponds exactly with the
                    original face the block was at. */
-                
+
                 if (abs (face_direction [0]) > 0.1)
                     colours [face_direction [0] < 0.0 ? 4 : 5]
                             [block_coords_to_index
-                                     (cube, block->transformation [13])]
+                                     (cube,  block->transformation [13])]
                             [block_coords_to_index
-                                     (cube, block->transformation [14])] = face;
+                                     (cube,  block->transformation [14])] = face;
 
                 else if (abs (face_direction [1]) > 0.1)
                     colours [face_direction [1] < 0.0 ? 2 : 3]
                             [block_coords_to_index
-                                     (cube, block->transformation [12])]
+                                     (cube,  block->transformation [12])]
                             [block_coords_to_index
-                                     (cube, block->transformation [14])] = face;
+                                     (cube,  block->transformation [14])] = face;
 
                 else
                     colours [face_direction [2] < 0.0 ? 0 : 1]
                             [block_coords_to_index
-                                     (cube, block->transformation [12])]
+                                     (cube,  block->transformation [12])]
                             [block_coords_to_index
-                                     (cube, block->transformation [13])] = face;
+                                     (cube,  block->transformation [13])] = face;
             }
-    
 
-    /* Now the colours array should be completely populated, we can manufacture
+
+    /* Now the colours array should be completely populated,  we can manufacture
        our scheme object. */
 
-    scm_face_vector = scm_c_make_vector (6, SCM_UNSPECIFIED);
+    scm_face_vector = scm_c_make_vector (6,  SCM_UNSPECIFIED);
 
     for (face = 0; face < 6; ++face)
     {
-        int i, j;
-        
+        int i,  j;
+
         SCM scm_block_vector
             = scm_c_make_vector (cube->cube_size * cube->cube_size,
                                  SCM_UNSPECIFIED);
@@ -718,20 +699,19 @@ SCM make_scm_cube (const Cube *const cube)
         for (i = 0; i < cube->cube_size; ++i)
             for (j = 0; j < cube->cube_size; ++j)
                 scm_vector_set_x (scm_block_vector,
-                                  SCM_MAKINUM (i + cube->cube_size * j),
-                                  SCM_MAKINUM (colours [face] [i] [j]));
+                                  scm_from_int (i + cube->cube_size * j),
+                                  scm_from_int (colours [face] [i] [j]));
 
         scm_vector_set_x (scm_face_vector,
-                          SCM_MAKINUM (face),
+                          scm_from_int (face),
                           scm_block_vector);
     }
-    
-    return scm_cons (scm_list_5 (SCM_MAKINUM (1),
-                                 SCM_MAKINUM (3),
-                                 SCM_MAKINUM (cube->cube_size),
-                                 SCM_MAKINUM (cube->cube_size),
-                                 SCM_MAKINUM (cube->cube_size)),
+
+    return scm_cons (scm_list_5 (scm_from_int (1),
+                                 scm_from_int (3),
+                                 scm_from_int (cube->cube_size),
+                                 scm_from_int (cube->cube_size),
+                                 scm_from_int (cube->cube_size)),
                      scm_face_vector);
 }
 
-#endif  /* Defined HAVE_GUILE. */
