@@ -4,7 +4,7 @@
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License,  or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,31 +13,32 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef GLAREA_H
 #define GLAREA_H
 
-#include "gnubik.h"
+#include <gtk/gtk.h>
 
 
 extern GLdouble fovy;
-extern GLdouble cp_near, cp_far;
+extern GLdouble cp_near,  cp_far;
 
 
-void re_initialize_glarea();
+void re_initialize_glarea (void);
 
 
-void register_gl_callbacks(t_widget glxarea);
-t_widget create_gl_area(t_widget containerWidget, t_widget adjacentWidget);
+void register_gl_callbacks (GtkWidget * glxarea);
+GtkWidget * create_gl_area (GtkWidget * containerWidget,  GtkWidget * adjacentWidget);
 
 
-void modelViewInit(void);
+void modelViewInit (void);
 
-void postRedisplay();
+void postRedisplay (void);
 
-void lighting_init(void);
+void lighting_init (void);
+
+void projection_init (int jitter);
 
 #endif
