@@ -3,7 +3,7 @@
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License,  or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,16 +12,12 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef GUILE_HOOKS_H
 #define GUILE_HOOKS_H
 
-#include "../config.h"
-
-#ifdef HAVE_GUILE
 
 #include <libguile.h>
 #include <gtk/gtk.h>
@@ -29,25 +25,22 @@
 /* Data type to implement a singly-linked list of GtkItemFactoryEntry
    objects. */
 
-typedef struct _Menu_Item_List 
+typedef struct _Menu_Item_List
 {
     GtkItemFactoryEntry entry;
     char *callback_data;
     struct _Menu_Item_List *next;
-    
 } Menu_Item_List;
 
 
 
 /* The method which seeks out all scripts and executes them. The scripts can
-   callback to the C world to register themselves. On completion, the function
+   callback to the C world to register themselves. On completion,  the function
    returns a list of registered items. The function must be called exactly
    once. */
 
-Menu_Item_List *startup_guile_scripts ();
+Menu_Item_List *startup_guile_scripts (void);
 
 
 
-#endif /* defined HAVE_GUILE. */
-
 #endif /* defined GUILE_HOOKS_H. */
