@@ -1,11 +1,11 @@
 /*
 
-    A little library to do quarternion arithmetic 
+    A little library to do quarternion arithmetic
     Copyright (C) 2003  John Darrington
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License,  or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -14,14 +14,12 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #ifndef QUARTERNION_H
 #define QUARTERNION_H
 
 #include "txfm.h"
-#include "gnubik.h"
 
 struct quarternion {
   float w;
@@ -33,16 +31,16 @@ struct quarternion {
 typedef struct quarternion Quarternion;
 
 
-void quarternion_from_rotation(Quarternion *q,vector u,float theta) ;
+void quarternion_from_rotation (Quarternion *q,  vector u,  float theta) ;
 
-void quarternion_print(const Quarternion *q) ;
+void quarternion_print (const Quarternion *q) ;
 
-void quarternion_to_matrix(Matrix M, const Quarternion *q) ;
+void quarternion_to_matrix (Matrix M,  const Quarternion *q) ;
 
 /* Pre multiply q1 by q2 */
-void quarternion_pre_mult(Quarternion *q1, const Quarternion *q2) ;
+void quarternion_pre_mult (Quarternion *q1,  const Quarternion *q2) ;
 
-void quarternion_set_to_unit(Quarternion *q) ;
+void quarternion_set_to_unit (Quarternion *q) ;
 
 
 #endif /* QUARTERNION_H */
