@@ -1,11 +1,11 @@
 /*
 
-    A little library to do matrix arithmetic 
+    A little library to do matrix arithmetic
     Copyright (C) 1998  John Darrington
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License,  or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -14,10 +14,9 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
-static const char RCSID[]="$Id: txfm.c,v 1.2 2004/01/05 13:36:17 dale_mellor Exp $";
+static const char RCSID[]="$Id: txfm.c,v 1.3 2008/01/16 10:35:14 jmd Exp $";
 
 #include <stdio.h>
 #include "txfm.h"
@@ -25,39 +24,39 @@ static const char RCSID[]="$Id: txfm.c,v 1.2 2004/01/05 13:36:17 dale_mellor Exp
 
 /* print out the location of a point.  For debug only */
 void
-plot( point p)
+plot ( point p)
 {
 	int i;
 
-	for( i=0; i < MATRIX_DIM; i++) {
-		printf("%f\t", p[i] );
+	for ( i=0; i < MATRIX_DIM; i++) {
+		printf ("%f\t",  p[i] );
 	}
-	putchar('\n');
+	putchar ('\n');
 }
 
 
 
 
 
-/* Pre-multiply a point or vector x, by matrix M */
-void 
-transform( const Matrix M, pv  x)
+/* Pre-multiply a point or vector x,  by matrix M */
+void
+transform ( const Matrix M,  pv  x)
 {
-	int i,j;
+	int i,  j;
 
 	/* Temporary point variable for result */
-	pv q={0,0,0,0};
+	pv q={0, 0, 0, 0};
 	
 
 	/* for each row */
-	for(i=0;i < MATRIX_DIM; i++) {
+	for (i=0;i < MATRIX_DIM; i++) {
 		/* for each column */
 		for ( j=0; j < MATRIX_DIM; j++)
 			 q[i] += M[i+MATRIX_DIM*j] * x[j] ;
 	}
 
 	/* Now copy  q into x */
-	for(i=0;i < MATRIX_DIM; i++)
+	for (i=0;i < MATRIX_DIM; i++)
 		x[i]=q[i];
 	
 }
@@ -65,64 +64,64 @@ transform( const Matrix M, pv  x)
 
 
 /* print a matrix on the stdout.  For debugging */
-void 
-showMatrix(const Matrix M)
+void
+showMatrix (const Matrix M)
 {
-	int i,j;
+	int i,  j;
 
 	/* for each row */
-	for( i=0; i < MATRIX_DIM; i++) {
+	for ( i=0; i < MATRIX_DIM; i++) {
 		/* for each column */
 		for ( j=0; j<MATRIX_DIM; j++) {
-			printf("%f\t",(float) M[i+(MATRIX_DIM*j)] );
+			printf ("%f\t", (float) M[i+(MATRIX_DIM*j)] );
 		}
-		putchar('\n');
+		putchar ('\n');
 	}
 }
 
 
 
 
-/* Pre-multiply a matrix N, by matrix M */
-void 
-pre_mult( const Matrix M, Matrix N)
+/* Pre-multiply a matrix N,  by matrix M */
+void
+pre_mult ( const Matrix M,  Matrix N)
 {
-	int i,j;
+	int i,  j;
 	int k;
 
 	/* Temporary Matrix variable for result */
 	Matrix T = {
-		0,0,0,0,
-		0,0,0,0,
-		0,0,0,0,
-		0,0,0,0
+		0, 0, 0, 0,
+		0, 0, 0, 0,
+		0, 0, 0, 0,
+		0, 0, 0, 0
 	};
 
 	
 
-	for(k=0;k < MATRIX_DIM ; k++) {
-		for(i=0;i < MATRIX_DIM ; i++) {
+	for (k=0;k < MATRIX_DIM ; k++) {
+		for (i=0;i < MATRIX_DIM ; i++) {
 			for ( j=0; j < MATRIX_DIM; j++) {
-				 T[i+k*MATRIX_DIM] += 
+				 T[i+k*MATRIX_DIM] +=
 					M[i+MATRIX_DIM*j] * N[j+MATRIX_DIM*k];
 			}
 		}
 	}
 
 	/* Now copy  T into N */
-	for(i=0;i < MATRIX_DIM * MATRIX_DIM; i++)
+	for (i=0;i < MATRIX_DIM * MATRIX_DIM; i++)
 		N[i]=T[i];
 	
 }
 
 
 
-/* Set matrix element x,y to value */
+/* Set matrix element x,  y to value */
 void
-set(Matrix M, int x, int y, float value)
+set (Matrix M,  int x,  int y,  float value)
 {
-  assert(x <= MATRIX_DIM);
-  assert(y <= MATRIX_DIM);
+  assert (x <= MATRIX_DIM);
+  assert (y <= MATRIX_DIM);
 
   M[x + MATRIX_DIM * y ] = value;
 
@@ -130,26 +129,26 @@ set(Matrix M, int x, int y, float value)
 
 /* Create a vector by taking the difference of 2 points */
 void
-vector_from_points(point p1, point p2, vector v)
+vector_from_points (point p1,  point p2,  vector v)
 {
   int i;
 
-  for(i = 0 ; i < MATRIX_DIM ; ++i ) 
+  for (i = 0 ; i < MATRIX_DIM ; ++i )
     v[i] = p2[i] - p1[i];
 
-  assert(v[MATRIX_DIM-1] == 0.0);
+  assert (v[MATRIX_DIM-1] == 0.0);
 }
 
 
 /* Return zero if any corresponding components of the two vectors are not equal,
    otherwise return one to indicate the vectors are identical. */
 int
-vectors_equal(const vector v1, const vector v2)
+vectors_equal (const vector v1,  const vector v2)
 {
     int i;
- 
+
     for (i = 0; i < 4; ++i)
-        if (v1 [i]  !=  v2 [i]) 
+        if (v1 [i]  !=  v2 [i])
             return 0;
 
     return 1;
