@@ -1,11 +1,10 @@
 /*
-
     A few functions to return version number and miscellaneous info.
     Copyright (C) 1998  John Darrington
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License,  or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -14,21 +13,20 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <string.h>
 #include "version.h"
-#include "../config.h"
+#include <config.h>
 #include <stdio.h>
 
-static const char RCS_ID[]="$Id: version.c,v 1.6 2004/01/05 13:36:17 dale_mellor Exp $";
+static const char RCS_ID[]="$Id: version.c,v 1.8 2008/02/01 11:54:03 jmd Exp $";
 
 
 /* Extract the revision number from this file's rcs string  */
 const char *
-get_version_string(void)
+get_version_string (void)
 {
 	return VERSION;
 }
@@ -36,20 +34,19 @@ get_version_string(void)
 char copyleft_notice[]=
 "\n"
 "    GNUbik  -- A 3 dimensional magic cube game.\n"
-"    Copyright (C) 1998, 2003  John Darrington\n"
-"                  2004        John Darrington, Dale Mellor\n"
+"    Copyright (C) 1998,  2003  John Darrington\n"
+"                  2004,  2008  John Darrington,  Dale Mellor\n"
 "\n"
 "    This program is free software; you can redistribute it and/or modify\n"
 "    it under the terms of the GNU General Public License as published by\n"
-"    the Free Software Foundation; either version 2 of the License, or\n"
+"    the Free Software Foundation; either version 3 of the License,  or\n"
 "    (at your option) any later version.\n"
 "\n"
-"    This program is distributed in the hope that it will be useful,\n"
+"    This program is distributed in the hope that it will be useful, \n"
 "    but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
 "    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
 "    GNU General Public License for more details.\n"
 "\n"
 "    You should have received a copy of the GNU General Public License\n"
-"    along with this program; if not, write to the Free Software\n"
-"    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA\n"
+"    along with this program.  If not, see <http://www.gnu.org/licenses/>.\n"
 ;
